#include<stdio.h> 
#include<stdlib.h> 
#include<string.h> 
#include<math.h> 
#include<limits.h> 

// Automata celulares de Wolfram
// Codificacao multispin das 256 regras 
// Em "Cellular Automata and Complexity", S.Wolfram, ISBN: 0-201-62664-0
// Tabela 1, pag. 516

#define MAXRULES 256 // Number of CA automata rules

void (*grammar[MAXRULES])(unsigned long *) = {NULL};

void rule0(unsigned long *w){
  (*w) = 0;
}
void rule1(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1));
}
void rule2(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1));
}
void rule3(unsigned long *w){
 (*w) = ((~(*w))<<1)&(~(*w));
}
void rule4(unsigned long *w){
 (*w) = ((~(*w))<<1)&(*w)&((~(*w))>>1);
}
void rule5(unsigned long *w){
 (*w) = ((~(*w))<<1)&((~(*w))>>1);
}
void rule6(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w))&((*w)>>1));
}
void rule7(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule8(unsigned long *w){
 (*w) = ((~(*w))<<1)&(*w)&((*w)>>1);
}
void rule9(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule10(unsigned long *w){
 (*w) = ((~(*w))<<1)&((*w)>>1);
}
void rule11(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((~(*w))<<1)&((*w)>>1));
}
void rule12(unsigned long *w){
 (*w) = ((~(*w))<<1)&(*w);
}
void rule13(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule14(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((~(*w))<<1)&((*w)>>1));
}
void rule15(unsigned long *w){
 (*w) = ((~(*w))<<1);
}
void rule16(unsigned long *w){
 (*w) = ((*w)<<1)&(~(*w))&((~(*w))>>1);
}
void rule17(unsigned long *w){
 (*w) = (~(*w))&((~(*w))>>1);
}
void rule18(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(~(*w))&((*w)>>1));
}
void rule19(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule20(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((~(*w))>>1));
}
void rule21(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((~(*w))>>1));
}
void rule22(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w))&((*w)>>1));
}
void rule23(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule24(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule25(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1));
}
void rule26(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule27(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule28(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule29(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule30(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w))|(((~(*w))<<1)&((*w)>>1));
}
void rule31(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((~(*w))<<1));
}
void rule32(unsigned long *w){
 (*w) = ((*w)<<1)&(~(*w))&((*w)>>1);
}
void rule33(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(~(*w))&((*w)>>1));
}
void rule34(unsigned long *w){
 (*w) = (~(*w))&((*w)>>1);
}
void rule35(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|((~(*w))&((*w)>>1));
}
void rule36(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w))&((*w)>>1));
}
void rule37(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&((~(*w))>>1));
}
void rule38(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule39(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule40(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule41(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule42(unsigned long *w){
 (*w) = ((~(*w))&((*w)>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule43(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|((~(*w))&((*w)>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule44(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&(*w));
}
void rule45(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule46(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|((~(*w))&((*w)>>1));
}
void rule47(unsigned long *w){
 (*w) = ((~(*w))&((*w)>>1))|(((~(*w))<<1));
}
void rule48(unsigned long *w){
 (*w) = ((*w)<<1)&(~(*w));
}
void rule49(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((*w)<<1)&(~(*w)));
}
void rule50(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|((~(*w))&((*w)>>1));
}
void rule51(unsigned long *w){
 (*w) = (~(*w));
}
void rule52(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)>>1)&(~(*w)));
}
void rule53(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&(~(*w)));
}
void rule54(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w)))|((~(*w))&((*w)>>1));
}
void rule55(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|((~(*w)));
}
void rule56(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((*w)>>1))|(((*w)<<1)&(~(*w)));
}
void rule57(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1))|(((*w)>>1)&(~(*w)));
}
void rule58(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((~(*w))<<1)&((*w)>>1));
}
void rule59(unsigned long *w){
 (*w) = (((~(*w))<<1)&((*w)>>1))|((~(*w)));
}
void rule60(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((~(*w))<<1)&(*w));
}
void rule61(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&(~(*w)))|(((~(*w))<<1)&(*w));
}
void rule62(unsigned long *w){
 (*w) = (((~(*w))<<1)&((*w)>>1))|(((*w)<<1)&(~(*w)))|(((~(*w))<<1)&(*w));
}
void rule63(unsigned long *w){
 (*w) = ((~(*w)))|(((~(*w))<<1));
}
void rule64(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1));
}
void rule65(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w)&((~(*w))>>1));
}
void rule66(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w))&((*w)>>1));
}
void rule67(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule68(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1));
}
void rule69(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1));
}
void rule70(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|((~(*w))&((*w)>>1));
}
void rule71(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule72(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule73(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule74(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule75(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)))|(((~(*w))<<1)&((*w)>>1));
}
void rule76(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule77(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule78(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule79(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((~(*w))<<1));
}
void rule80(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1));
}
void rule81(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((*w)<<1)&((~(*w))>>1));
}
void rule82(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&((~(*w))>>1));
}
void rule83(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule84(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1));
}
void rule85(unsigned long *w){
 (*w) = (((~(*w))>>1));
}
void rule86(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1));
}
void rule87(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((~(*w))>>1));
}
void rule88(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((*w)>>1))|(((*w)<<1)&((~(*w))>>1));
}
void rule89(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1))|(((*w)<<1)&((~(*w))>>1));
}
void rule90(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule91(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule92(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule93(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((~(*w))>>1));
}
void rule94(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule95(unsigned long *w){
 (*w) = (((~(*w))>>1))|(((~(*w))<<1));
}
void rule96(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w))&((*w)>>1));
}
void rule97(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w))&((*w)>>1));
}
void rule98(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule99(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)))|((~(*w))&((*w)>>1));
}
void rule100(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|((*w)&((~(*w))>>1));
}
void rule101(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1));
}
void rule102(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule103(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|((*w)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule104(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule105(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&(*w)&((*w)>>1));
}
void rule106(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|((~(*w))&((*w)>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule107(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)))|((~(*w))&((*w)>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule108(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|((*w)&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule109(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((*w)>>1))|(((~(*w))<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1))|(((~(*w))<<1)&(*w));
}
void rule110(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|((*w)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule111(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|((~(*w))&((*w)>>1))|(((~(*w))<<1));
}
void rule112(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((*w)<<1)&(~(*w)));
}
void rule113(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((*w)<<1)&((~(*w))>>1))|(((*w)<<1)&(~(*w)));
}
void rule114(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule115(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|((~(*w)));
}
void rule116(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w)));
}
void rule117(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((~(*w))>>1));
}
void rule118(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|((*w)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule119(unsigned long *w){
 (*w) = (((~(*w))>>1))|((~(*w)));
}
void rule120(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((*w)>>1))|(((*w)<<1)&((~(*w))>>1))|(((*w)<<1)&(~(*w)));
}
void rule121(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1))|(((*w)<<1)&((~(*w))>>1))|(((*w)<<1)&(~(*w)));
}
void rule122(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule123(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1))|((~(*w)));
}
void rule124(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((*w)<<1)&(~(*w)))|(((~(*w))<<1)&(*w));
}
void rule125(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((~(*w))<<1)&(*w))|(((~(*w))>>1));
}
void rule126(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|((~(*w))&((*w)>>1))|(((~(*w))<<1)&(*w));
}
void rule127(unsigned long *w){
 (*w) = (((~(*w))>>1))|((~(*w)))|(((~(*w))<<1));
}
void rule128(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1));
}
void rule129(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule130(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule131(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule132(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule133(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1))|(((~(*w))<<1)&((~(*w))>>1));
}
void rule134(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule135(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1))|(((~(*w))<<1)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule136(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1));
}
void rule137(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule138(unsigned long *w){
 (*w) = (((~(*w))<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule139(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|((*w)&((*w)>>1));
}
void rule140(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|((*w)&((*w)>>1));
}
void rule141(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule142(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((~(*w))<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule143(unsigned long *w){
 (*w) = ((*w)&((*w)>>1))|(((~(*w))<<1));
}
void rule144(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule145(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1));
}
void rule146(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule147(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule148(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule149(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((~(*w))>>1));
}
void rule150(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&(*w)&((*w)>>1));
}
void rule151(unsigned long *w){
 (*w) = (((*w)<<1)&(*w)&((*w)>>1))|((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)));
}
void rule152(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule153(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule154(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule155(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|((~(*w))&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule156(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w))|((*w)&((*w)>>1));
}
void rule157(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|((~(*w))&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule158(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w))&((~(*w))>>1))|(((~(*w))<<1)&(*w))|(((~(*w))<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule159(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|((*w)&((*w)>>1))|(((~(*w))<<1));
}
void rule160(unsigned long *w){
 (*w) = (((*w)<<1)&((*w)>>1));
}
void rule161(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule162(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((*w)<<1)&((*w)>>1));
}
void rule163(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((*w)<<1)&((*w)>>1));
}
void rule164(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule165(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule166(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|((~(*w))&((*w)>>1))|(((*w)<<1)&((*w)>>1));
}
void rule167(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule168(unsigned long *w){
 (*w) = (((*w)<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule169(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule170(unsigned long *w){
 (*w) = (((*w)>>1));
}
void rule171(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((*w)>>1));
}
void rule172(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((*w)<<1)&((*w)>>1));
}
void rule173(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule174(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w))|(((*w)>>1));
}
void rule175(unsigned long *w){
 (*w) = (((~(*w))<<1))|(((*w)>>1));
}
void rule176(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((*w)<<1)&((*w)>>1));
}
void rule177(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule178(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|((~(*w))&((*w)>>1))|(((*w)<<1)&((*w)>>1));
}
void rule179(unsigned long *w){
 (*w) = (((*w)<<1)&((*w)>>1))|((~(*w)));
}
void rule180(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w)))|(((*w)<<1)&((*w)>>1));
}
void rule181(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((~(*w))<<1)&((*w)>>1))|(((*w)<<1)&((*w)>>1));
}
void rule182(unsigned long *w){
 (*w) = (((~(*w))<<1)&(*w)&((~(*w))>>1))|(((*w)<<1)&(~(*w)))|((~(*w))&((*w)>>1))|(((*w)<<1)&((*w)>>1));
}
void rule183(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1))|((~(*w)));
}
void rule184(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|((*w)&((*w)>>1));
}
void rule185(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|((~(*w))&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule186(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((*w)>>1));
}
void rule187(unsigned long *w){
 (*w) = ((~(*w)))|(((*w)>>1));
}
void rule188(unsigned long *w){
 (*w) = (((*w)<<1)&((*w)>>1))|(((*w)<<1)&(~(*w)))|(((~(*w))<<1)&(*w));
}
void rule189(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((*w)<<1)&((*w)>>1))|(((~(*w))<<1)&(*w));
}
void rule190(unsigned long *w){
 (*w) = (((*w)<<1)&(~(*w)))|(((~(*w))<<1)&(*w))|(((*w)>>1));
}
void rule191(unsigned long *w){
 (*w) = ((~(*w)))|(((~(*w))<<1))|(((*w)>>1));
}
void rule192(unsigned long *w){
 (*w) = (((*w)<<1)&(*w));
}
void rule193(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule194(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&(*w));
}
void rule195(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((*w)<<1)&(*w));
}
void rule196(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule197(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule198(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|((*w)&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule199(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)))|(((*w)<<1)&(*w));
}
void rule200(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|((*w)&((*w)>>1));
}
void rule201(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w))|((*w)&((*w)>>1));
}
void rule202(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|(((~(*w))<<1)&((*w)>>1));
}
void rule203(unsigned long *w){
 (*w) = (((~(*w))<<1)&((*w)>>1))|(((~(*w))<<1)&(~(*w)))|(((*w)<<1)&(*w));
}
void rule204(unsigned long *w){
 (*w) = ((*w));
}
void rule205(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|((*w));
}
void rule206(unsigned long *w){
 (*w) = (((~(*w))<<1)&((*w)>>1))|((*w));
}
void rule207(unsigned long *w){
 (*w) = (((~(*w))<<1))|((*w));
}
void rule208(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule209(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule210(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule211(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&(~(*w)))|(((*w)<<1)&(*w));
}
void rule212(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule213(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|(((~(*w))>>1));
}
void rule214(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((*w)>>1))|(((*w)<<1)&((~(*w))>>1))|((*w)&((~(*w))>>1))|(((*w)<<1)&(*w));
}
void rule215(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((*w)<<1)&(*w))|(((~(*w))>>1));
}
void rule216(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule217(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|((~(*w))&((~(*w))>>1))|((*w)&((*w)>>1));
}
void rule218(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|(((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1));
}
void rule219(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1))|(((*w)<<1)&(*w));
}
void rule220(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|((~(*w)));
}
void rule221(unsigned long *w){
 (*w) = (((~(*w))<<1))|((*w));
}
void rule222(unsigned long *w){
 (*w) = (((*w)<<1)&((~(*w))>>1))|(((~(*w))<<1)&((*w)>>1))|((*w));
}
void rule223(unsigned long *w){
 (*w) = (((~(*w))<<1))|(((~(*w))>>1))|((*w));
}
void rule224(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|(((*w)<<1)&((*w)>>1));
}
void rule225(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w))|(((*w)<<1)&((*w)>>1));
}
void rule226(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|((~(*w))&((*w)>>1));
}
void rule227(unsigned long *w){
 (*w) = (((*w)<<1)&((*w)>>1))|(((~(*w))<<1)&(~(*w)))|(((*w)<<1)&(*w));
}
void rule228(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule229(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|(((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1));
}
void rule230(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|((*w)&((~(*w))>>1))|((~(*w))&((*w)>>1));
}
void rule231(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|((~(*w))&((*w)>>1))|(((*w)<<1)&(*w));
}
void rule232(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|(((*w)<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule233(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w))&((~(*w))>>1))|(((*w)<<1)&(*w))|(((*w)<<1)&((*w)>>1))|((*w)&((*w)>>1));
}
void rule234(unsigned long *w){
 (*w) = (((*w)<<1)&(*w))|(((*w)>>1));
}
void rule235(unsigned long *w){
 (*w) = (((~(*w))<<1)&(~(*w)))|(((*w)<<1)&(*w))|(((*w)>>1));
}
void rule236(unsigned long *w){
 (*w) = (((*w)<<1)&((*w)>>1))|((*w));
}
void rule237(unsigned long *w){
 (*w) = (((~(*w))<<1)&((~(*w))>>1))|(((*w)<<1)&((*w)>>1))|((*w));
}
void rule238(unsigned long *w){
 (*w) = ((*w))|(((*w)>>1));
}
void rule239(unsigned long *w){
 (*w) = (((~(*w))<<1))|((*w))|(((*w)>>1));
}
void rule240(unsigned long *w){
 (*w) = (((*w)<<1));
}
void rule241(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|(((*w)<<1));
}
void rule242(unsigned long *w){
 (*w) = ((~(*w))&((*w)>>1))|(((*w)<<1));
}
void rule243(unsigned long *w){
 (*w) = ((~(*w)))|(((*w)<<1));
}
void rule244(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|(((*w)<<1));
}
void rule245(unsigned long *w){
 (*w) = (((~(*w))>>1))|(((*w)<<1));
}
void rule246(unsigned long *w){
 (*w) = ((*w)&((~(*w))>>1))|((~(*w))&((*w)>>1))|(((*w)<<1));
}
void rule247(unsigned long *w){
 (*w) = (((~(*w))>>1))|((~(*w)))|(((*w)<<1));
}
void rule248(unsigned long *w){
 (*w) = ((*w)&((*w)>>1))|(((*w)<<1));
}
void rule249(unsigned long *w){
 (*w) = ((~(*w))&((~(*w))>>1))|((*w)&((*w)>>1))|(((*w)<<1));
}
void rule250(unsigned long *w){
 (*w) = (((*w)<<1))|(((*w)>>1));
}
void rule251(unsigned long *w){
 (*w) = ((~(*w)))|(((*w)<<1))|(((*w)>>1));
}
void rule252(unsigned long *w){
 (*w) = (((*w)<<1))|((*w));
}
void rule253(unsigned long *w){
 (*w) = (((~(*w))>>1))|(((*w)<<1))|((*w));
}
void rule254(unsigned long *w){
 (*w) = (((*w)<<1))|((*w))|(((*w)>>1));
}
void rule255(unsigned long *w){
 (*w) = 1;
}
void define_functions(void){
   (*(grammar+0))=&rule0;
   (*(grammar+1))=&rule1;
   (*(grammar+2))=&rule2;
   (*(grammar+3))=&rule3;
   (*(grammar+4))=&rule4;
   (*(grammar+5))=&rule5;
   (*(grammar+6))=&rule6;
   (*(grammar+7))=&rule7;
   (*(grammar+8))=&rule8;
   (*(grammar+9))=&rule9;
   (*(grammar+10))=&rule10;
   (*(grammar+11))=&rule11;
   (*(grammar+12))=&rule12;
   (*(grammar+13))=&rule13;
   (*(grammar+14))=&rule14;
   (*(grammar+15))=&rule15;
   (*(grammar+16))=&rule16;
   (*(grammar+17))=&rule17;
   (*(grammar+18))=&rule18;
   (*(grammar+19))=&rule19;
   (*(grammar+20))=&rule20;
   (*(grammar+21))=&rule21;
   (*(grammar+22))=&rule22;
   (*(grammar+23))=&rule23;
   (*(grammar+24))=&rule24;
   (*(grammar+25))=&rule25;
   (*(grammar+26))=&rule26;
   (*(grammar+27))=&rule27;
   (*(grammar+28))=&rule28;
   (*(grammar+29))=&rule29;
   (*(grammar+30))=&rule30;
   (*(grammar+31))=&rule31;
   (*(grammar+32))=&rule32;
   (*(grammar+33))=&rule33;
   (*(grammar+34))=&rule34;
   (*(grammar+35))=&rule35;
   (*(grammar+36))=&rule36;
   (*(grammar+37))=&rule37;
   (*(grammar+38))=&rule38;
   (*(grammar+39))=&rule39;
   (*(grammar+40))=&rule40;
   (*(grammar+41))=&rule41;
   (*(grammar+42))=&rule42;
   (*(grammar+43))=&rule43;
   (*(grammar+44))=&rule44;
   (*(grammar+45))=&rule45;
   (*(grammar+46))=&rule46;
   (*(grammar+47))=&rule47;
   (*(grammar+48))=&rule48;
   (*(grammar+49))=&rule49;
   (*(grammar+50))=&rule50;
   (*(grammar+51))=&rule51;
   (*(grammar+52))=&rule52;
   (*(grammar+53))=&rule53;
   (*(grammar+54))=&rule54;
   (*(grammar+55))=&rule55;
   (*(grammar+56))=&rule56;
   (*(grammar+57))=&rule57;
   (*(grammar+58))=&rule58;
   (*(grammar+59))=&rule59;
   (*(grammar+60))=&rule60;
   (*(grammar+61))=&rule61;
   (*(grammar+62))=&rule62;
   (*(grammar+63))=&rule63;
   (*(grammar+64))=&rule64;
   (*(grammar+65))=&rule65;
   (*(grammar+66))=&rule66;
   (*(grammar+67))=&rule67;
   (*(grammar+68))=&rule68;
   (*(grammar+69))=&rule69;
   (*(grammar+70))=&rule70;
   (*(grammar+71))=&rule71;
   (*(grammar+72))=&rule72;
   (*(grammar+73))=&rule73;
   (*(grammar+74))=&rule74;
   (*(grammar+75))=&rule75;
   (*(grammar+76))=&rule76;
   (*(grammar+77))=&rule77;
   (*(grammar+78))=&rule78;
   (*(grammar+79))=&rule79;
   (*(grammar+80))=&rule80;
   (*(grammar+81))=&rule81;
   (*(grammar+82))=&rule82;
   (*(grammar+83))=&rule83;
   (*(grammar+84))=&rule84;
   (*(grammar+85))=&rule85;
   (*(grammar+86))=&rule86;
   (*(grammar+87))=&rule87;
   (*(grammar+88))=&rule88;
   (*(grammar+89))=&rule89;
   (*(grammar+90))=&rule90;
   (*(grammar+91))=&rule91;
   (*(grammar+92))=&rule92;
   (*(grammar+93))=&rule93;
   (*(grammar+94))=&rule94;
   (*(grammar+95))=&rule95;
   (*(grammar+96))=&rule96;
   (*(grammar+97))=&rule97;
   (*(grammar+98))=&rule98;
   (*(grammar+99))=&rule99;
   (*(grammar+100))=&rule100;
   (*(grammar+101))=&rule101;
   (*(grammar+102))=&rule102;
   (*(grammar+103))=&rule103;
   (*(grammar+104))=&rule104;
   (*(grammar+105))=&rule105;
   (*(grammar+106))=&rule106;
   (*(grammar+107))=&rule107;
   (*(grammar+108))=&rule108;
   (*(grammar+109))=&rule109;
   (*(grammar+110))=&rule110;
   (*(grammar+111))=&rule111;
   (*(grammar+112))=&rule112;
   (*(grammar+113))=&rule113;
   (*(grammar+114))=&rule114;
   (*(grammar+115))=&rule115;
   (*(grammar+116))=&rule116;
   (*(grammar+117))=&rule117;
   (*(grammar+118))=&rule118;
   (*(grammar+119))=&rule119;
   (*(grammar+120))=&rule120;
   (*(grammar+121))=&rule121;
   (*(grammar+122))=&rule122;
   (*(grammar+123))=&rule123;
   (*(grammar+124))=&rule124;
   (*(grammar+125))=&rule125;
   (*(grammar+126))=&rule126;
   (*(grammar+127))=&rule127;
   (*(grammar+128))=&rule128;
   (*(grammar+129))=&rule129;
   (*(grammar+130))=&rule130;
   (*(grammar+131))=&rule131;
   (*(grammar+132))=&rule132;
   (*(grammar+133))=&rule133;
   (*(grammar+134))=&rule134;
   (*(grammar+135))=&rule135;
   (*(grammar+136))=&rule136;
   (*(grammar+137))=&rule137;
   (*(grammar+138))=&rule138;
   (*(grammar+139))=&rule139;
   (*(grammar+140))=&rule140;
   (*(grammar+141))=&rule141;
   (*(grammar+142))=&rule142;
   (*(grammar+143))=&rule143;
   (*(grammar+144))=&rule144;
   (*(grammar+145))=&rule145;
   (*(grammar+146))=&rule146;
   (*(grammar+147))=&rule147;
   (*(grammar+148))=&rule148;
   (*(grammar+149))=&rule149;
   (*(grammar+150))=&rule150;
   (*(grammar+151))=&rule151;
   (*(grammar+152))=&rule152;
   (*(grammar+153))=&rule153;
   (*(grammar+154))=&rule154;
   (*(grammar+155))=&rule155;
   (*(grammar+156))=&rule156;
   (*(grammar+157))=&rule157;
   (*(grammar+158))=&rule158;
   (*(grammar+159))=&rule159;
   (*(grammar+160))=&rule160;
   (*(grammar+161))=&rule161;
   (*(grammar+162))=&rule162;
   (*(grammar+163))=&rule163;
   (*(grammar+164))=&rule164;
   (*(grammar+165))=&rule165;
   (*(grammar+166))=&rule166;
   (*(grammar+167))=&rule167;
   (*(grammar+168))=&rule168;
   (*(grammar+169))=&rule169;
   (*(grammar+170))=&rule170;
   (*(grammar+171))=&rule171;
   (*(grammar+172))=&rule172;
   (*(grammar+173))=&rule173;
   (*(grammar+174))=&rule174;
   (*(grammar+175))=&rule175;
   (*(grammar+176))=&rule176;
   (*(grammar+177))=&rule177;
   (*(grammar+178))=&rule178;
   (*(grammar+179))=&rule179;
   (*(grammar+180))=&rule180;
   (*(grammar+181))=&rule181;
   (*(grammar+182))=&rule182;
   (*(grammar+183))=&rule183;
   (*(grammar+184))=&rule184;
   (*(grammar+185))=&rule185;
   (*(grammar+186))=&rule186;
   (*(grammar+187))=&rule187;
   (*(grammar+188))=&rule188;
   (*(grammar+189))=&rule189;
   (*(grammar+190))=&rule190;
   (*(grammar+191))=&rule191;
   (*(grammar+192))=&rule192;
   (*(grammar+193))=&rule193;
   (*(grammar+194))=&rule194;
   (*(grammar+195))=&rule195;
   (*(grammar+196))=&rule196;
   (*(grammar+197))=&rule197;
   (*(grammar+198))=&rule198;
   (*(grammar+199))=&rule199;
   (*(grammar+200))=&rule200;
   (*(grammar+201))=&rule201;
   (*(grammar+202))=&rule202;
   (*(grammar+203))=&rule203;
   (*(grammar+204))=&rule204;
   (*(grammar+205))=&rule205;
   (*(grammar+206))=&rule206;
   (*(grammar+207))=&rule207;
   (*(grammar+208))=&rule208;
   (*(grammar+209))=&rule209;
   (*(grammar+210))=&rule210;
   (*(grammar+211))=&rule211;
   (*(grammar+212))=&rule212;
   (*(grammar+213))=&rule213;
   (*(grammar+214))=&rule214;
   (*(grammar+215))=&rule215;
   (*(grammar+216))=&rule216;
   (*(grammar+217))=&rule217;
   (*(grammar+218))=&rule218;
   (*(grammar+219))=&rule219;
   (*(grammar+220))=&rule220;
   (*(grammar+221))=&rule221;
   (*(grammar+222))=&rule222;
   (*(grammar+223))=&rule223;
   (*(grammar+224))=&rule224;
   (*(grammar+225))=&rule225;
   (*(grammar+226))=&rule226;
   (*(grammar+227))=&rule227;
   (*(grammar+228))=&rule228;
   (*(grammar+229))=&rule229;
   (*(grammar+230))=&rule230;
   (*(grammar+231))=&rule231;
   (*(grammar+232))=&rule232;
   (*(grammar+233))=&rule233;
   (*(grammar+234))=&rule234;
   (*(grammar+235))=&rule235;
   (*(grammar+236))=&rule236;
   (*(grammar+237))=&rule237;
   (*(grammar+238))=&rule238;
   (*(grammar+239))=&rule239;
   (*(grammar+240))=&rule240;
   (*(grammar+241))=&rule241;
   (*(grammar+242))=&rule242;
   (*(grammar+243))=&rule243;
   (*(grammar+244))=&rule244;
   (*(grammar+245))=&rule245;
   (*(grammar+246))=&rule246;
   (*(grammar+247))=&rule247;
   (*(grammar+248))=&rule248;
   (*(grammar+249))=&rule249;
   (*(grammar+250))=&rule250;
   (*(grammar+251))=&rule251;
   (*(grammar+252))=&rule252;
   (*(grammar+253))=&rule253;
   (*(grammar+254))=&rule254;
   (*(grammar+255))=&rule255;
}


void draw_string(unsigned long w,int NBITS, unsigned long *mask){
  int i;
  for(i=0;i<NBITS;i++){ // NBITS definido em limits.h
    if((w&mask[i])!=0) printf("#");
    else printf(" ");
  }
  printf("\n");
}

int main(int argv, char **argc){
  unsigned long w,*mask;
  int t,tmax,regra,NBITS;
  char fname[100];
  FILE *out_ptr;

  if(argv != 4){
    printf("Uso: %s <regra> <iteracoes> <cond. inicial>\n",argc[0]);
    exit(1);
  }

  w=1UL;
  NBITS=1;
  w=w<<1;
  while(w!=0){
    NBITS++;
    w=w<<1;
  }

  mask=malloc(NBITS*sizeof(unsigned long));
  mask[0]=w=1UL;
  for(t=1;t<NBITS;t++)
    mask[t]=mask[t-1]<<1;
  printf("NBITS=%d\n",NBITS);  
  
  regra=atoi(argc[1]);
  tmax=atoi(argc[2]);
  w=strtoul(argc[3],NULL,10);

  define_functions();

  printf("Regra %d com %d passos e w=%lu\n",regra,tmax,w);
  draw_string(w,NBITS,mask);
  for(t=1;t<tmax;t++){    
    (*(grammar+regra))(&w);
    draw_string(w,NBITS,mask);
  }
  return(0);
}
