#include<stdio.h>
#include<string.h>
#include<stdlib.h>
#include<math.h>

// Gera, recursivamente, o traingulo de Sierpinski fazendo, a cada
// iteracao, uma reescala x'=2^(-L)*x e transformando um triangulo
// em tres triangulos.Veja:
// http://mathworld.wolfram.com/SierpinskiSieve.html

void draw_triangle(double x, double y, int L,FILE *ptr){
  double x1,y1,x2,y2,x3,y3;

    x1=x;
    y1=y;
    x2=x+(6.0/pow(2.0,L));
    y2=y;
    x3=x+(3.0/pow(2.0,L));
    y3=y+(4.0/pow(2.0,L));
    fprintf(ptr,"%e %e\n%e %e\n%e %e\n%e %e\n\n",x1,y1,x2,y2,x3,y3,x1,y1);
}


void triangle(double x, double y, int n, int N,FILE *ptr){
  int L;

  L=n;
  if(L<N){ // Se iteracao L nao for a N-esima
    L++; 
    triangle(x,y,L,N,ptr);  // Desenha um triangulo a partir do pto (0,0)
    triangle(x+(3.0/pow(2.0,L)),y+(4.0/pow(2.0,L)),L,N,ptr);
    triangle(x+(6.0/pow(2.0,L)),y,L,N,ptr);
  }else{ // Imprime o triangulo gerado na N-esima iteracao
    draw_triangle(x,y,L,ptr);
  }
}

int main(int argv, char **argc){
  int N,Ni,Nf;
  FILE *out_ptr;
  char arq[1000],list[1000]="";

  if((argv!=2)&&(argv!=3)){
    printf("Uso: %s <numero de iteracoes> <num. max. iteracoes (opcional)>>\n",argc[0]);
    exit(1);   
  }
  Ni=atoi(argc[1]);
  if(argv==3)
    Nf=atoi(argc[2]);
  else
    Nf=Ni;

  for(N=Ni;N<=Nf;N++){    
    sprintf(arq,"sierpinski-N%d.data",N);
    out_ptr=fopen(arq,"w");
    (void)triangle(0.0,0.0,0,N,out_ptr); // Desenha um triangulo a partir do pto (0,0)
    fclose(out_ptr);

    ////////////////////////////////////////////////////////////////////    
    ////////////////////////////////////////////////////////////////////    
    ////// Visualizacao grafica no gnuplot /////////////////////////////
    // Para ser carregado no gnuplot 
    // No gnuplot, digite (para o caso de N=4 iteracoes):
    // gnuplot> load "sierpinski-N4.gnp" onde x eh o tamanho do sistema
    // Se voce rodou o programa com 2 parametros de entrada (argv=3)
    // o programa gera um gif animado com as imagens geradas pelo 
    // gnuplot e pelo programa convert, do pacote imagemagick


    sprintf(arq,"sierpinski-N%d.gnp",N); 
    out_ptr=fopen(arq,"w");
    
    fprintf(out_ptr,"unset xtics\n unset ytics\n");
    sprintf(arq,"set title \"Carpete de Sierpinski\\n %d iteracoes\"\n",N);
    fprintf(out_ptr,"%s",arq);
    if(argv==3){
      sprintf(arq,"set terminal gif\n set output \"sierpinski-N%d.gif\"\n",N);
      fprintf(out_ptr,"%s",arq);
      sprintf(arq,"sierpinski-N%d.gif ",N); 
      strcat(list,arq);
    }
    sprintf(arq,"plot \"sierpinski-N%d.data\" with filledcurves title \"\"\n",N);
    fprintf(out_ptr,"%s",arq);
    fclose(out_ptr);
    sprintf(arq,"gnuplot sierpinski-N%d.gnp",N);
    system(arq);
    if(argv==3){
      sprintf(arq,"convert -rotate 270 sierpinski-N%d.gif sierpinski-N%d.gif",N,N);
      system(arq);
    }
  }
  // Cria gif animado (precisa do pacote imagemagick no linux)
  sprintf(arq,"convert -adjoin -delay 50 -loop 0 %s sierpinski.gif",list);
  system(arq);
  // Cria filme avi (precisa do pacote ffmpe)
  //  system("ffmpeg -r 1 -i sierpinski-N\%1d.gif -y -an sierpinski.avi");
  return(0);
}
