#include<stdio.h>
#include<stdlib.h>
#include<string.h>
#include<math.h>

//////////////////////////////////////////
// mapa logistico 
// x_{n+1}=lambda*x_n*(1-x_n)
//
// Programa que ilustra a evolucao temporal de x
// e a respectiva imagem no mapa de retorno 

void main(int argv,char **argc){

#define NBINS  1000 // dx em H(x)dx vale 1/NBINS
  unsigned long t,transient,max_iter,H[NBINS];
  double x,xa,x0,lambda;
  char arq[100];
  FILE *out_steps,*out_evol;

  if(argv != 5){
    printf("Uso: %s <lambda> <x0> <max_iter> <transient>, onde 0.0<=x0<=1.0 \n",argc[0]);
    exit(1);
  }
  lambda=atof(argc[1]);
  x0=atof(argc[2]);
  max_iter=(unsigned long)atol(argc[3]);
  transient=(unsigned long)atol(argc[4]);
  if((x0>=1.0)||(x0<0.0) || (max_iter < 0)){
    printf("Uso: <%s> <lambda> <x0> <max_iter>, onde 0.0<=x0<=1.0 \n",argc[0]);
    exit(1);
  }
  xa=x0;
  sprintf(arq,"evol_l%1.3lf_t%lu.data",lambda,max_iter);
  out_evol=fopen(arq,"w");
  sprintf(arq,"steps_l%1.3lf_t%lu.data",lambda,max_iter);
  out_steps=fopen(arq,"w");
  fprintf(out_steps,"%lf 0.0\n",xa);
  fprintf(out_steps,"%lf %lf\n",xa,xa);
  memset(H,0,sizeof(H));
  for(t=0;t<max_iter;t++){
    x=lambda*xa*(1-xa);
    fprintf(out_evol,"%lu %lf\n",t,x);
    if(fabs(x-xa)>0.00001){
      fprintf(out_steps,"%lf %lf\n",xa,xa);
      fprintf(out_steps,"%lf %lf\n",xa,x);
      fprintf(out_steps,"%lf %lf\n",x,x);
    }
    if(t>transient){
      H[(unsigned long)(x*NBINS)]++;
    }
    xa=x;
  }
  fclose(out_steps);
  fclose(out_evol);
  sprintf(arq,"histogram_l%1.3lf_t%lu.data",lambda,max_iter);
  out_evol=fopen(arq,"w");
  for(t=0;t<NBINS;t++){
    if(H[t]>0)
      fprintf(out_evol,"%lf %e\n",(double)t/(double)NBINS,(double)H[t]/((double)(max_iter-transient)));
  }
  fclose(out_evol);
}
/* O caso lambda=4.0 tem solucao analitica para H(x)
 H(x) = 1 /(pi*[x*(1 - x)]^1/2)
 Que eh a distribuicao beta com parametros  a = 0.5  e  b = 0.5
*/
